/* General styles for all menus */
.cbp-spmenu {
	background: #222222;
	position: fixed;
}

.cbp-spmenu a {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	color: #ffffff;
	text-decoration: none;
	
	display: block;
	font-size: 16px;
	font-weight: 300;
}

.cbp-spmenu a:active {
	background: #333333;
	color: #ffffff;
}

/* Vertical menu that slides from the left or right */

.cbp-spmenu-left {
	left: -240px;
	width: 240px;
	height: 100%;
	top: 50px;
	z-index: 11114;
}

.cbp-spmenu-left a {
	border-bottom: 1px solid #000000;
	padding: 1em;
}

.cbp-spmenu-right {
	right: -400px;
	width: 300px;
	height: 100%;
	top: 50px;
	z-index: 11114;
	overflow: hidden;
}

.cbp-spmenu-right.cbp-spmenu-open {
	right: 0px;
}

.cbp-spmenu-left.cbp-spmenu-open {
	left: 0px;
}

/* Transitions */

.cbp-spmenu,
.cbp-spmenu-push {
	-webkit-transition: all 0.3s ease;
	-webkit-filter: translateZ(0);
	-webkit-backface-visibility: hidden;
	-moz-transition: all 0.3s ease;
	transition: all 0.3s ease;
}

/* Example media queries */


