/*
//
//   BOXES.
//
*/
.minbox {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	overflow:hidden;
  width: 95%;
  margin: auto;
	text-align: left;
}

.box {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
  height:56px;
  width: 95%;
  margin: auto;
	border-bottom-style: solid;
	border-color: #333333;
	border-width: 1px;
	text-align: left;
}

.boxLeft {
	height:50px;
	width:56px;
	float:left;
	padding-top: 3px;
	text-align: left;
}
.boxLeftIcon {
	height:50px;
	width:56px;
	float:left;
	text-align: center;
	line-height: 65px;
	color: #888888;
}

.boxRight {
	height:56px;
 	width:30px;
  float: right;
  line-height: 68px;
  color: #666666;
  text-align: center;
}

.boxCenter {
	height: 100%;
	text-align: left;
	overflow: hidden;
	white-space: nowrap;
}
.boxCenter2 {
	height: 100%;
	text-align: left;
	overflow:auto;
	white-space: nowrap;
}
.boxCenter2 h1 {
	font-size: 17px;
	font-weight: 100;
	line-height: 0px;
	color: lightgreen !important;
}
.boxCenter2 h3 {
	color: #999999;
	font-size: 12px;
	font-weight: 100;
	line-height: 3px;
}
.boxCenter h1 {
	color: #ffffff;
	font-size: 17px;
	font-weight: 100;
	line-height: 0px;
}
.boxCenter h3 {
	color: #999999;
	font-size: 12px;
	font-weight: 100;
	line-height: 3px;
}

/*
//
//   OTHER BOXES.
//
*/

.headerBox{
	width: 95%;
  margin-left:auto;
  margin-right:auto;
  height: 56px;
	border-bottom-style: solid;
	border-color: #999999;
	border-width: 1px;
	text-align:left;
}

.box3{
	width: 95%;
  margin-left:auto;
  margin-right:auto;
  height: 56px;
	border-bottom-style: solid;
	border-color: #999999;
	border-width: 1px;
	text-align:left;
	
}
.box3 h1{
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	font-size: 17px;
	font-weight: 400;
	color: #777777;
	line-height: 86px;
}
.box2{
	width: 95%;
  margin-left:auto;
  margin-right:auto;
  height: 45px;
	border-bottom-style: solid;
	border-color: #333333;
	border-width: 1px;
	text-align:left;
	padding-left: 6px;
}
.box2 h1{
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	font-size: 17px;
	font-weight: 400;
	color: #777777;
}

/*
//
// PLAY QUEUE
//
*/
.queuePerm {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	background: #222222;
	position: fixed;
	float: right;
	right: 0px;
	width: 300px;
	height: 100%;
	top: 50px;
	z-index: 11114;
	overflow: hidden;
}
.queueHeader {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	color: #ffffff;
	background: #222222;
	position: fixed;
	float: right;
	right: 0px;
	width: 300px;
	height: 50px;
	top: 0px;
	z-index: 11114;
	overflow: hidden;
	text-align: center;
	line-height: 50px;
}


.queueSpacer {
	background: #222222;
	position: relative;
	float: right;
	right: 0px;
	width: 300px;
	height: 50px;
	top: 0px;
	z-index: 11110;
	overflow: hidden;
}


.queueWrapper {
	overflow: auto;
	width: 330px;
	height: 100%;
}
.queueContent {
	height: 100%;
	width: 300px;
}

.queueBox {
	width: 98%;
	height: 40px;
	margin: auto;
	border-bottom-style: solid;
	border-color: #333333;
	border-width: 1px;
	text-align: left;
}
.queueBoxLeft{
	width: 43px;
	height: 40px;
	float: left;
}

.queueBoxRight{
	height: 40px;
 	width: 40px;
  float: right;
  line-height: 40px;
  color: #666666;
  text-align: center;
}

.queueBoxCenter{
	height: 40px;
	text-align: left;
	overflow: hidden;
	white-space: nowrap;
}

.queueBoxCenter h1 {
	color: #ffffff;
	font-size: 14px;
	font-weight: 100;
	line-height: 0px;
	padding-top: 14px;
	margin: 0 auto;
}

.queueBoxCenter h2 {
	color: lightgreen;
	font-size: 14px;
	font-weight: 100;
	line-height: 0px;
	padding-top: 14px;
	margin: 0 auto;
}

.queueBoxCenter h3 {
	color: #999999;
	font-size: 11px;
	font-weight: 100;
	line-height: 3px;
}

/*
//
// CONTEXT MENU
//
*/

.contextClose {
	height: 30px;
	width: 100%;
	position: absolute;
	bottom: 5px;
	text-align: center;
	
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	font-size: 17px;
	font-weight: 400;
	color: #777777;

}

.contextMenu {
	position: fixed;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	z-index: 11115;
}
.contextMask {
	position: fixed;
	width: 100%;
	height: 100%;
	background-color: #000000;
	opacity: 0.5;
}
.contextOuter {
	top: 50%;
  left: 50%;
  position: absolute;
}
.contextInner {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	font-size: 13px;
	font-weight: 600;
	
	position: relative;
	width: 300px;
	margin-left: -150px;
	height: 400px;
	margin-top: -200px;
	background: #111111;
	border-style: solid;
	border-width: 1px;
	border-color: #777777;
	border-radius: 3px;
	text-align: center;
	padding: 3px;
}

/*
//
// MENU
//
*/

.menumask {
	display: 		none;
	opacity:    0.9; 
  background: #000; 
  width:      100%;
  height:     100%; 
  z-index:    11113;
  top:        50px; 
  left:       0; 
  position:   fixed; 
}
input:-webkit-autofill,
input:-webkit-autofill:hover,
input:-webkit-autofill:focus,
input:-webkit-autofill:active {
    -webkit-transition: "color 9999s ease-out, background-color 9999s ease-out";
    -webkit-transition-delay: 9999s;
}
input:focus {
   outline: none;
}

/*
//
// ALBUMS, ARTISTS, PLAYLISTS
//
*/

.albumList {
	padding-top: 50px;
	margin: 0 auto;
	width: 100%;
	background: #111111;
	min-height: 340px;
	z-index: 10;
	//-webkit-backface-visibility: hidden;
	//-webkit-transform: translateZ(0);
}

.lfmInfo {
	width: 95%;
	margin: 0 auto;
	position: fixed;
	text-align: center;
	left: 0;
	margin-right: auto;
	margin-left: auto;
	z-index: -1;

}

.lfmInfo h2 {
	color: #ffffff;
	font-size: 10px;
	font-style: normal;
	font-variant: normal;
	font-weight: 100;
	line-height: 11px;	
}

.lfmInfo h1 {
	color: #ffffff;
	font-size: 13px;
	font-style: normal;
	font-variant: normal;
	font-weight: 800;
	line-height: 10px;	
}

.playMenu {
	background-color: #111111;
	position: absolute;
	top: 290px;
	width: 100%;
	z-index: 100;
	text-align: center;
	height: 50px
	margin: 0 auto;
	margin-right: auto;
	margin-left: auto;
	overflow: hidden;
}

.playMenuContainer{
	width: 95%;
  margin-left:auto;
  margin-right:auto;
  height: 50px;
	border-bottom-style: solid;
	border-color: #444444;
	border-width: 2px;
	text-align:left;
}

.menuBox {
	float: left;
	height: 100%;
	text-align: left;
	margin-right: 25px;
	line-height: 55px;
	color: #888888;
	font-size: 13px;
}

.blurBackground{
	top: 0;
	left: 0;
	margin-right: auto;
	margin-left: auto;
	position: fixed;
	overflow: hidden;
	width: 100%;
	background-color: #000000;
	
	height: 340px;
	z-index: -1;
}

.blurBackImg {
  overflow: hidden;
	width: 50%;
	height: 50%;

	-webkit-transform-origin: top left;
	-webkit-transform: scale(2) !important;
	-webkit-perspective: 1000;
	-webkit-backface-visibility: hidden;
	-webkit-transform: translateZ(0);

	transform-origin: top left;
	transform: scale(2);
}

.blurBackImg2 {
	position: fixed;
	width: 100%;
	height: 100%;
	background-size: cover;
	background-repeat: no-repeat;
	background-position: 50% 50%;
	
	-webkit-filter: blur(18px) brightness(0.7);
  -webkit-perspective: 1000;
	filter: blur(18px) brightness(0.7);
}



/*
//
// BODY AND BACKGROUNDS
//
*/

body {
  background-color: #111111;
  color: #FFFFFF;
  padding: 0px;
	margin: 0px;
} 
body div {
	padding: 0px;
	margin: 0px;
}

body a {
    text-decoration: none;
}


.main {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	overflow: hidden;
  text-align: center;
  height: 100%;
  padding: 0px;
	margin: 0 auto;

}

/*
//
// NOW PLAYING
//
*/

.npBackground{
	top: 0;
	right: 0;
	left: 0;
	margin-right: auto;
	margin-left: auto;
	position: fixed;
	overflow: hidden;
	width: 100%;
	height: 100%;
	background-color: #000000;
	z-index: -1;
}

.npBackImg {
  overflow: hidden;
	width: 50%;
	height: 50%;

	-webkit-transform-origin: top left;
	-webkit-transform: scale(2) !important;
	-webkit-perspective: 1000;
	-webkit-backface-visibility: hidden;
	-webkit-transform: translateZ(0);

	transform-origin: top left;
	transform: scale(2);
}

.npBackImg2 {
	position: fixed;
	width: 100%;
	height: 100%;
	background-size: cover;
	background-repeat: no-repeat;
	background-position: 50% 50%;
	
	-webkit-filter: blur(25px) brightness(0.5);
  -webkit-perspective: 1000;
	filter: blur(25px) brightness(0.5);
	-webkit-backface-visibility: hidden;
	-webkit-transform: translateZ(0);
}

.nowPlaying {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
  text-align: center;
  padding: 0px;
	margin: 0 auto;
	overflow: hidden;
	top: 0;
	bottom: 0;
	height: 500px;
}
.nowPlaying h1 {
	color: #FFFFFF;
	font-size: 16px;
	font-weight: 600;
	line-height: 16px;
}

.nowPlaying h2 {
	color: #9f9f9f;
	font-size: 13px;
	font-weight: 200;
	line-height: 13px;
	margin: 0 auto;
	padding: 4px;
}

.nowPlaying p {
	color: #9f9f9f;
	font-size: 12px;
	font-weight: 100;
	line-height: 12px;
}
.nowPlaying a {
	color: #ffffff;
}

#npTable{
	width: 100%;
	height: 100%;
}

#npTop {
	height: 60px;
	width: 100%;
	overflow: hidden;
}

#npMiddle {
	width: 100%;
	height: 100%;
}
.npImage{
	margin: 0 auto;
  Height: 100%;
	width: 95%;
	background-position: center; 
	background-size: contain;
	background-repeat: no-repeat;
}

.npImageWide{
  height: 90%;
	width: 90%;
	background-position: center; 
	background-size: contain;
	background-repeat: no-repeat;
}

#npBottom {
	width: 100%;
	height: 160px;
  text-align: center;
}

.npVolControlContainer{
	margin: 0 auto;
	margin-top: 3px;
	height: 20px;
	width: 95%;
	max-width: 700px;
	overflow: hidden;
}
.npVolLeft{
	width: 40px;
	padding-top: 0px;
	line-height: 0px;
	float: left;
	text-align: left;
}
.npVolRight{
	width: 40px;
	padding-top: 0px;
	line-height: 0px;
	float: right;
	text-align: right;
}

.npVol {
	overflow: hidden;
	text-align: center;
	height: 20px;
}

.npDetails{
	width: 100%;
	text-align: center;
	height: 90px;
	overflow: auto;
}

.npProgressContainer{
	margin: 0 auto;
	width: 100%;
	height: 20px;
	max-width: 700px;
}

.npProgressLeft{
	float: left;
	text-align: left;
	width: 40px;
	height: 20px;
}

.npProgressRight{
	float: right;
	text-align: right;
	width: 40px;
	height: 20px;
}

.npProgressCenter {
	overflow: hidden;
	height: 20px;
	text-align: center;
}

.npProgressWrap {
	height: 2px;
	width: 100%;
  background: #111;
  margin: 0px auto;
  margin-top: 9px;
}
.npProgressBar {
	background: #ffffff;
	width: 0%;
	height: 100%;
}

.npButtonContainer{
	margin: 0 auto;
	height: 50px;
	width: 95%;
	max-width: 700px;
	overflow: hidden;
}
.npButton {
	padding-top: 10px;
	float: left;
}
.npButtonPlay {
	text-align: center;
	float: left;
}

.npButtonSide {
	padding-top: 17px;
	float: left;
}
#randomOff {
	color: #777777 !important;
}
#randomOn {
	color: #ffffff !important;
}
#repeatOff {
	color: #777777 !important;
}
#repeatOn {
	color: #ffffff !important;
}



/*
//
// HEADER AND SEARCH
//
*/
.menuPerm {
	height: 50px;
	top: 0px;
	display: inline;
	float: left;
}

.menuPerm a{
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	color: #ffffff;
	text-decoration: none;
	
	display: inline;
	
	font-size: 16px !important;
	font-weight: 300 !important;
	line-height: 48px !important;

}

.pageTitle {
	overflow: hidden;
	display: inline;
}

.searchBox, .searchBox active, .searchBox hover {
	-webkit-appearance: none;
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	font-size: 17px;
	background: transparent;
	padding:4px 4px 4px 4px;
	margin: 0px;
	margin-top: 13px;
	border: 0px;
	border-bottom: 1px solid #555555;
	width: 300px;
	height: 18px;
	color: #ffffff;
	overflow: hidden
}
.searchButton {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	background: transparent;
	border: 0px solid #555555;
	color: #FFFFFF;
}

.searchReset{
	font-size: 20px;
	margin-left: -25px;
	color: #888888;
}

.headerBG {
	background: rgb(22, 22, 22);
	z-index: -1;
	position: fixed;
  left: 0;
  right: 0;
  top: 0;
  height: 50px;
}

.header {
	position: fixed;
  left: 0;
  right: 0;
  top: 0;
  height: 50px;
  z-index: 11118;
}

.header h1 {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	color: #ffffff;
	font-size: 16px;
	font-style: normal;
	font-variant: normal;
	font-weight: 700;
	line-height: 30px;
}

.header a{
	color: #ffffff;
	font-size: 25px;
	text-decoration: none;
}

.headerLeft {
	width: 50px;
	height: 50px;
	float: left;
	text-align: center;
	padding-top: 9px;
}
.headerRight {
	height: 50px;
	width: 50px;
	float: right;
	text-align: center;
	padding-top: 9px;
}

.headerCenter {
	overflow: hidden;
	height: 50px;
	text-align: left;
}

/*
//
// FOOTER
//
*/


.footer {
	background: #222222;
  color: #ffffff;
  position: fixed;
  left: 0;
  right: 0;
  bottom: 0;
  height: 50px; 
  z-index: 11119; 
}
.footer h1 {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	color: #FFFFFF;
	font-size: 16px;
	font-style: normal;
	font-variant: normal;
	font-weight: 400;
	line-height: 10px;
}
.footer h3 {
	font-family: Calibri,Candara,Segoe,Segoe UI,Optima,Arial,sans-serif;
	color: #ffffff;
	font-size: 11px;
	font-style: normal;
	font-variant: normal;
	font-weight: 200;
	line-height: 0px;
}

.footer_right {
  position: absolute;
  color: #FFFFFF;
  right: 13px;
  bottom: 13px;
  width: 70px;
  //padding-right: 5px;
  text-align: right;
  text-decoration: none;
}

.footer_right a{
  color: #FFFFFF;
  font-size:30px;
  font-weight: 100;
  line-height: 0px;
}

.footer_center {
  position: absolute;
  width: 100%;
  top:0px;
  padding-top: 2px;
  text-align: center;
}

.footerBackground{
	margin-right: auto;
	margin-left: auto;
	overflow: hidden;
	width: 100%;
	background-color: #222222;
	
	height: 50px;
	z-index: -1;

}

.footerBackImg {
  overflow: hidden;
	width: 50%;
	height: 50%;

	-webkit-transform-origin: top left;
	-webkit-transform: scale(2) !important;
	-webkit-perspective: 1000;
	-webkit-backface-visibility: hidden;
	-webkit-transform: translateZ(0);

	transform-origin: top left;
	transform: scale(2);
}

.footerBackImg2 {
	position: fixed;
	width: 100%;
	height: 100%;
	background-size: cover;
	background-repeat: no-repeat;
	background-position: 50% 50%;
		
	-webkit-filter: blur(15px) brightness(0.7);
  -webkit-perspective: 1000;	
	filter: blur(15px) brightness(0.7);

}

.footerProgress {
	position: fixed;
	bottom: 50px;
  width: 100%;
  height: 2px;
}
.footerProgressWrap {
  background: #111;
  margin: -2px auto;
  overflow: hidden;
  position: relative;
}
.footerProgressBar {
	background: #999999;
	width: 0%;
	left: 0;
	position: absolute;
	top: 0;
}